==> humhub-1.4.2.tar.gz: humhub-1.4.2/protected/humhub/modules/space/messages/sv/manage.php <==
<?php
return array (
  '-' => '',
  '<strong>Confirm</strong> image deleting' => '<strong>Bekräfta</strong> radering av bild',
  '<strong>Create</strong> new space' => '<strong>Skapa</strong> nytt nätverk',
  '<strong>Manage</strong> members' => '',
  '<strong>Members</strong>' => '<strong>Medlemmar</strong>',
  '<strong>Modify</strong> space image' => '<strong>Ändra</strong> nätverksbild',
  '<strong>Security</strong> settings' => '<strong>Säkerhetsinställningar</strong>',
  '<strong>Space</strong> Modules' => '',
  '<strong>Space</strong> settings' => '',
  'Actions' => 'Åtgärder',
  'Activated' => '',
  'Add <strong>Modules</strong>' => 'Lägg till moduler',
  'Advanced access settings' => 'Avancerade åtkomstinställningar',
  'Archive' => 'Arikivera',
  'Are you sure, that you want to delete this space? All published content will be removed!' => 'Är du säker på att du vill ta bort detta nätverk? Allt publicerat material kommer tas bort!',
  'Are you sure? *ALL* module data for this space will be deleted!' => '',
  'As owner of this space you can transfer this role to another administrator in space.' => '',
  'Cancel' => 'Avbryt',
  'Cancel Membership' => '',
  'Choose if new content should be public or private by default' => '',
  'Choose the kind of membership you want to provide for this workspace.' => '',
  'Choose the security level for this workspace to define the visibleness.' => '',
  'Close' => 'Stäng',
  'Configure' => 'Konfigurera',
  'Currently there are no modules available for this space!' => '',
  'Delete' => 'Ta bort',
  'Disable' => 'Inaktivera',
  'Do you really want to delete your profile image?' => 'Vill du verkligen radera profilbilden?',
  'Do you really want to delete your title image?' => '',
  'Don\'t receive notifications for new content' => '',
  'Enable' => 'Aktivera',
  'Enhance this space with modules.' => '',
  'Hide posts on dashboard' => '',
  'Invited By' => '',
  'Members' => 'Medlemmar',
  'Modules' => 'Moduler',
  'Next' => 'Nästa',
  'Owner' => 'Ägare',
  'Pending Approvals' => 'Väntande godkännanden',
  'Pending Invites' => 'Väntande inbjudningar',
  'Permissions are assigned to different user-roles. To edit a permission, select the user-role you want to edit and change the drop-down value of the given permission.' => '',
  'Please provide your password to continue!' => 'Vänligen ange ditt lösenord för att fortsätta!',
  'Receive Notifications for new content' => '',
  'Remove from space' => 'Ta bort från nätverk',
  'Role' => '',
  'Save' => 'Spara',
  'Security' => 'Säkerhet',
  'Send & decline' => 'Sänd & avböj',
  'Show all' => 'Visa alla',
  'Show posts on dashboard' => '',
  'Space name' => 'Nätverksnamn',
  'Space owner' => 'Ägare av nätverk',
  'Stream (Default)' => 'Flöde (Standard)',
  'The url contains illegal characters!' => 'Url innehåller ogiltliga tecken!',
  'This option will hide new content from this space at your dashboard' => '',
  'This option will show new content from this space at your dashboard' => '',
  'Transfer ownership' => 'Flytta ägarskap',
  'Unarchive' => 'Återställ',
  'Your password' => 'Ditt lösenord',
  'e.g. example for {baseUrl}/s/example' => '',
  'never' => '',
  'space description' => 'nätverkets beskrivning ',
  'the default start page of this space for members' => '',
  'the default start page of this space for visitors' => '',
);

==> humhub-1.6.3.tar.gz: humhub-1.6.3/protected/humhub/modules/space/messages/sv/manage.php <==
<?php
return array (
  '-' => '',
  '<strong>Create</strong> new space' => '<strong>Skapa</strong> nytt nätverk',
  '<strong>Manage</strong> members' => '',
  '<strong>Members</strong>' => '<strong>Medlemmar</strong>',
  '<strong>Security</strong> settings' => '<strong>Säkerhetsinställningar</strong>',
  '<strong>Space</strong> Modules' => '',
  '<strong>Space</strong> settings' => '',
  'Actions' => 'Åtgärder',
  'Activated' => '',
  'Add <strong>Modules</strong>' => 'Lägg till moduler',
  'Advanced access settings' => 'Avancerade åtkomstinställningar',
  'Archive' => 'Arikivera',
  'Are you sure, that you want to delete this space? All published content will be removed!' => 'Är du säker på att du vill ta bort detta nätverk? Allt publicerat material kommer tas bort!',
  'Are you sure? *ALL* module data for this space will be deleted!' => '',
  'As owner of this space you can transfer this role to another administrator in space.' => '',
  'Cancel Membership' => '',
  'Choose if new content should be public or private by default' => '',
  'Choose the kind of membership you want to provide for this workspace.' => '',
  'Choose the security level for this workspace to define the visibleness.' => '',
  'Configure' => 'Konfigurera',
  'Currently there are no modules available for this space!' => '',
  'Delete' => 'Ta bort',
  'Disable' => 'Inaktivera',
  'Don\'t receive notifications for new content' => '',
  'Enable' => 'Aktivera',
  'Enhance this space with modules.' => '',
  'Hide posts on dashboard' => '',
  'Invited By' => '',
  'Members' => 'Medlemmar',
  'Modules' => 'Moduler',
  'Next' => 'Nästa',
  'Owner' => 'Ägare',
  'Pending Approvals' => 'Väntande godkännanden',
  'Pending Invites' => 'Väntande inbjudningar',
  'Permissions are assigned to different user-roles. To edit a permission, select the user-role you want to edit and change the drop-down value of the given permission.' => '',
  'Please type the name of the space to proceed.' => '',
  'Receive Notifications for new content' => '',
  'Remove from space' => 'Ta bort från nätverk',
  'Role' => '',
  'Security' => 'Säkerhet',
  'Send & decline' => 'Sänd &amp; avböj',
  'Show all' => 'Visa alla',
  'Show posts on dashboard' => '',
  'Space name' => 'Nätverksnamn',
  'Space owner' => 'Ägare av nätverk',
  'Stream (Default)' => 'Flöde (Standard)',
  'The url contains illegal characters!' => 'Url innehåller ogiltliga tecken!',
  'This option will hide new content from this space at your dashboard' => '',
  'This option will show new content from this space at your dashboard' => '',
  'Transfer ownership' => 'Flytta ägarskap',
  'Unarchive' => 'Återställ',
  'e.g. example for {baseUrl}/s/example' => '',
  'never' => '',
  'space description' => 'nätverkets beskrivning',
  'the default start page of this space for members' => '',
  'the default start page of this space for visitors' => '',
);
